@@ -271,10 +271,10 @@ def _build_windows_cmd(project):
     proj_path = os.path.abspath(project.project_path)
 
     if project.config.godot.local:
-        cmd = "start {0} --path {1}".format(os.path.abspath(project.config.godot.local), proj_path)
+        cmd = 'start "" "{0}" --path "{1}"'.format(os.path.abspath(project.config.godot.local), proj_path)
     else:
         godot_path = os.path.abspath("{0}/godot-{1}".format(project.repository_home, project.config.godot.version))
-        cmd = "start {0}\{1} --path {2}".format(godot_path, _get_godot_runtime(project), proj_path)
+        cmd = 'start "" "{0}\{1}" --path "{2}"'.format(godot_path, _get_godot_runtime(project), proj_path)
 
     return cmd
 
