@@ -384,14 +384,14 @@ godot_versions = {
     ':3.5.2::windows:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.5.2/rc1/mono/Godot_v3.5.2-rc1_mono_win32.zip',
     ':3.5.2::windows:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.5.2/rc1/mono/Godot_v3.5.2-rc1_mono_win64.zip',
 # 4.0
-    ':4.0::darwin::'                	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta16/Godot_v4.0-beta16_osx.universal.zip',
-    ':4.0::linux:32:'               	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta16/Godot_v4.0-beta16_x11.32.zip',
-    ':4.0::linux:64:'               	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta16/Godot_v4.0-beta16_x11.64.zip',
-    ':4.0::windows:64:'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta16/Godot_v4.0-beta16_win64.exe.zip',
-    ':4.0::windows:32:'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta16/Godot_v4.0-beta16_win32.exe.zip',
-    ':4.0::darwin::mono'              	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta16/mono/Godot_v4.0-beta16_mono_osx.universal.zip',
-    ':4.0::linux:32:mono'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta16/mono/Godot_v4.0-beta16_mono_x11_32.zip',
-    ':4.0::linux:64:mono'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta16/mono/Godot_v4.0-beta16_mono_x11_64.zip',
-    ':4.0::windows:64:mono'           	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta16/mono/Godot_v4.0-beta16_mono_win32.zip',
-    ':4.0::windows:32:mono'           	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta16/mono/Godot_v4.0-beta16_mono_win64.zip',
+    ':4.0::darwin::'                	: 'https://downloads.tuxfamily.org/godotengine/4.0/Godot_v4.0-stable_osx.universal.zip',
+    ':4.0::linux:32:'               	: 'https://downloads.tuxfamily.org/godotengine/4.0/Godot_v4.0-stable_x11.32.zip',
+    ':4.0::linux:64:'               	: 'https://downloads.tuxfamily.org/godotengine/4.0/Godot_v4.0-stable_x11.64.zip',
+    ':4.0::windows:64:'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/Godot_v4.0-stable_win64.exe.zip',
+    ':4.0::windows:32:'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/Godot_v4.0-stable_win32.exe.zip',
+    ':4.0::darwin::mono'              	: 'https://downloads.tuxfamily.org/godotengine/4.0/mono/Godot_v4.0-stable_mono_osx.universal.zip',
+    ':4.0::linux:32:mono'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/mono/Godot_v4.0-stable_mono_x11_32.zip',
+    ':4.0::linux:64:mono'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/mono/Godot_v4.0-stable_mono_x11_64.zip',
+    ':4.0::windows:64:mono'           	: 'https://downloads.tuxfamily.org/godotengine/4.0/mono/Godot_v4.0-stable_mono_win32.zip',
+    ':4.0::windows:32:mono'           	: 'https://downloads.tuxfamily.org/godotengine/4.0/mono/Godot_v4.0-stable_mono_win64.zip',
 }
